.. include:: /ad/ad_attention.inc

.. py:currentmodule:: plasmapy.analysis

.. _analysis:

===================
`plasmapy.analysis`
===================

.. toctree::
   :maxdepth: 1
   :caption: Sub-Packages & Modules

   Fit Functions </api_static/plasmapy.analysis.fit_functions>
   Swept Langmuir <swept_langmuir>
   Null Point Finder </api_static/plasmapy.analysis.nullpoint>

Notebooks
---------

.. nbgallery::
   :glob:
   :reversed:

   /notebooks/analysis/*

API
---

.. automodapi:: plasmapy.analysis
   :heading-chars: ^~
